:orphan:

`plasmapy.dispersion.numerical.kinetic_alfven_`
===============================================

.. currentmodule:: plasmapy.dispersion.numerical.kinetic_alfven_

.. automodapi:: plasmapy.dispersion.numerical.kinetic_alfven_
